@@ -3,8 +3,8 @@ import os
 
 from tqdm import tqdm
 
-from src.huffpress.generic import bin_to_dec, dec_to_bin, Mode
-from src.huffpress.huffman import create_huff_tree
+from huffpress.generic import bin_to_dec, dec_to_bin, Mode
+from huffpress.huffman import create_huff_tree
 
 
 def create_huff_sequence(huff: dict, itxt, verbose=False):
@@ -86,11 +86,3 @@ def compress(inp, verbose=False, mode=Mode.DEFAULT):
             return compress_file(inp, verbose=verbose)
         else:
             return compress_string(inp, verbose=verbose)
-
-
-def comp(fun):
-    def decorator(*args, **kwargs):
-        ret = fun(*args, **kwargs)
-        com_ret = compress_string(ret)
-        return com_ret
-    return decorator
